@@ -17,6 +17,7 @@ import concurrent.futures
 
 import grpc
 
+from flwr.common import GRPC_MAX_MESSAGE_LENGTH
 from flwr.proto import transport_pb2_grpc
 from flwr.server.client_manager import ClientManager
 from flwr.server.grpc_server import flower_service_servicer as fss
@@ -26,6 +27,7 @@ def start_insecure_grpc_server(
     client_manager: ClientManager,
     server_address: str,
     max_concurrent_workers: int = 1000,
+    max_message_length: int = GRPC_MAX_MESSAGE_LENGTH,
 ) -> grpc.Server:
     """Create grpc server and return registered FlowerServiceServicer instance.
 
@@ -37,8 +39,8 @@ def start_insecure_grpc_server(
         maximum_concurrent_rpcs=max_concurrent_workers,
         options=[
             ("grpc.max_concurrent_streams", max(100, max_concurrent_workers)),
-            ("grpc.max_send_message_length", 256 * 1024 * 1024),
-            ("grpc.max_receive_message_length", 256 * 1024 * 1024),
+            ("grpc.max_send_message_length", max_message_length),
+            ("grpc.max_receive_message_length", max_message_length),
         ],
     )
 
