@@ -86,7 +86,7 @@ class FedAvg(Strategy):
             return None
         return self.eval_fn(weights)
 
-    def on_configure_fit(
+    def configure_fit(
         self, rnd: int, weights: Weights, client_manager: ClientManager
     ) -> List[Tuple[ClientProxy, FitIns]]:
         """Configure the next round of training."""
@@ -108,7 +108,7 @@ class FedAvg(Strategy):
         # Return client/config pairs
         return [(client, fit_ins) for client in clients]
 
-    def on_configure_evaluate(
+    def configure_evaluate(
         self, rnd: int, weights: Weights, client_manager: ClientManager
     ) -> List[Tuple[ClientProxy, EvaluateIns]]:
         """Configure the next round of evaluation."""
@@ -139,7 +139,7 @@ class FedAvg(Strategy):
         # Return client/config pairs
         return [(client, evaluate_ins) for client in clients]
 
-    def on_aggregate_fit(
+    def aggregate_fit(
         self,
         rnd: int,
         results: List[Tuple[ClientProxy, FitRes]],
@@ -158,7 +158,7 @@ class FedAvg(Strategy):
         ]
         return aggregate(weights_results)
 
-    def on_aggregate_evaluate(
+    def aggregate_evaluate(
         self,
         rnd: int,
         results: List[Tuple[ClientProxy, EvaluateRes]],
@@ -176,9 +176,3 @@ class FedAvg(Strategy):
                 for _, evaluate_res in results
             ]
         )
-
-    def on_conclude_round(
-        self, rnd: int, loss: Optional[float], acc: Optional[float]
-    ) -> bool:
-        """Always continue training."""
-        return True
