@@ -12,10 +12,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 # ==============================================================================
-"""Implments compute classes for EC2."""
+"""Implements compute classes for EC2."""
 import concurrent.futures
 from contextlib import contextmanager
-from dataclasses import dataclass
 from itertools import groupby
 from logging import DEBUG, ERROR
 from typing import Dict, Iterator, List, Optional, Tuple
@@ -26,30 +25,11 @@ from paramiko.sftp_attr import SFTPAttributes
 from flwr.common.logger import log
 
 from .compute.adapter import Adapter
+from .instance import Instance
 
 ExecInfo = Tuple[str, str]
 
 
-# pylint: disable=too-many-instance-attributes
-@dataclass
-class Instance:
-    """Represents an instance."""
-
-    # Specs
-    name: str
-    group: str
-    num_cpu: int
-    num_ram: float
-    gpu: bool = False
-
-    # Runtime information
-    instance_id: Optional[str] = None
-    private_ip: Optional[str] = None
-    public_ip: Optional[str] = None
-    ssh_port: Optional[int] = None
-    state: Optional[str] = None
-
-
 class StartFailed(Exception):
     """Raised when cluster could not start."""
 
@@ -216,7 +196,8 @@ class Cluster:
             # pylint: disable=broad-except
             except Exception as exc:
                 log(
-                    ERROR, "Failed to start the cluster completely. Shutting down...",
+                    ERROR,
+                    "Failed to start the cluster completely. Shutting down...",
                 )
                 log(ERROR, exc)
 
@@ -281,6 +262,8 @@ class Cluster:
             stdout = stdout.readlines()
             stderr = stderr.readlines()
 
+        print(stdout, stderr)
+
         return stdout, stderr
 
     def exec_all(
